CSX Data Analysis Tools
=======================



[![Build Status](https://travis-ci.org/NSLS-II-CSX/csxtools.svg?branch=master)](https://travis-ci.org/NSLS-II-CSX/csxtools)
[![Coverage Status](https://coveralls.io/repos/NSLS-II-CSX/csxtools/badge.svg?branch=master&service=github)](https://coveralls.io/github/NSLS-II-CSX/csxtools?branch=master)
[![Code Health](https://landscape.io/github/NSLS-II-CSX/csxtools/master/landscape.svg?style=flat)](https://landscape.io/github/NSLS-II-CSX/csxtools/master)

Python library for tools to be used at the Coherent Soft X-ray scattering 
beamline at NSLS-II, (CSX, 23-ID)
